CHANGE LOG
==========

3.0.3
-----
- fix E402 in latest flake8 version

3.0.2
-----
- update celery to be inline with 3.1.19

3.0.1
-----
- make settings variables configurable via ENV

3.0.0
-----
- release as pip installable
- refactored namespace to use mc2
- allow deleting of app

2.0.0
-----
- Initial 2.0 release (non-backwards compatible)
- refactored code structure
- introduced controller base
- simplified model definitions

< 2.0
-----
- Mission Control for Universal Core
